ConnectionType

Enum ConnectionType 

pub enum ConnectionType {
    KeepAlive,
    Close,
    Upgrade,
}
Connection type

Variants



KeepAlive



Close



Upgrade

Implementations

Source

impl ConnectionType

pub fn resolve( headers_connection_type: Option<ConnectionType>, carry_over_connection_type: Option<ConnectionType>, http11: bool, ) -> Result<Self, HeadersMismatchError>

Resolve the connection type

Resolution is based on:

  • The connection type found in the headers, if any
  • (if the above is missing) based on the carry-over connection type, if any
  • (if the above is missing) based on the HTTP version

Parameters:

  • headers_connection_type: The connection type found in the headers, if any
  • carry_over_connection_type: The carry-over connection type (i.e. if this is a response, the carry_over_connection_type is the connection type of the request)
  • http11: Whether the HTTP protocol is 1.1
pub fn from_header(name: &str, value: &str) -> Option<Self>

Create a connection type from a header

If the header is not a Connection header, this method returns None

pub fn from_headers<'a, H>(headers: H) -> Option<Self>
where H: IntoIterator<Item = (&'a str, &'a str)>,

Create a connection type from headers

If multiple Connection headers are found, this method logs a warning and returns the last one If no Connection headers are found, this method returns None

pub fn raw_header(&self) -> (&str, &[u8])

Create a raw header from the connection type