edge_http::io

Module server

Structs

  • An HTTP server that can handle multiple requests concurrently.

Enums

Constants

Traits

  • A trait (async callback) for handling incoming HTTP requests

Functions

  • A convenience function to handle multiple HTTP requests over a single socket stream, using the specified handler.
  • A convenience function to handle a single HTTP request over a socket stream, using the specified handler.

Type Aliases

  • A type alias for an HTTP server with default buffer sizes.
  • A type alias for the HTTP server buffers (essentially, arrays of MaybeUninit)