Websocket utilities
Enums
- Websocket upgrade errors
Constants
Functions
- Check if the response is a Websocket upgrade response and if the upgrade was accepted
- Check if the request is a Websocket upgrade request
- Compute the response for a given
Sec-WebSocket-Key - Return ready-to-use WS upgrade request headers
- Return ready-to-use WS upgrade response headers